@@ -43,6 +43,8 @@ class AutocompleteMap(autocomplete_light.AutocompleteGenericBase):
         models.Protocol.objects.all(),
         models.Sex.objects.all(),
         models.Location.objects.all(),
+        models.Species.objects.all(),
+        models.Observer.objects.all(),
     )
 
     search_fields = (
@@ -51,6 +53,8 @@ class AutocompleteMap(autocomplete_light.AutocompleteGenericBase):
         (i18n_fieldnames('name')),
         (i18n_fieldnames('name')),
         ('name',),
+        ('standard_name',),
+        ('name',),
     )
 
 
