@@ -159,7 +159,7 @@ class SpeciesGroup(ChecklistsModel):
     name.help_text = _('The translated name of the group.')
 
     def __unicode__(self):
-        return "%s" % (self.name or self.genus)
+        return "%s (%s)" % (self.name, self.genus)
 
 
 class Rank(ChecklistsModel):
@@ -306,7 +306,7 @@ class Species(ChecklistsModel):
     status.help_text = _('Keywords describing the species status')
 
     def __unicode__(self):
-        return "%s" % (self.common_name or self.standard_name)
+        return self.standard_name
 
 
 class Location(ChecklistsModel):
@@ -372,7 +372,7 @@ class Location(ChecklistsModel):
     gridref.help_text = _('The grid reference of the location.')
 
     def __unicode__(self):
-        return "%s, %s" % (self.name, self.county)
+        return self.name
 
 
 class Activity(ChecklistsModel):
